@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2021, OFFIS e.V.
+ *  Copyright (C) 1994-2024, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -25,6 +25,7 @@
 #include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 #include "dcmtk/dcmdata/dctagkey.h"
 #include "dcmtk/dcmdata/dcvr.h"
+#include <cstring>
 
 /// constant describing an unlimited VM
 #define DcmVariableVM   -1
@@ -65,7 +66,7 @@ public:
      *  @param vmMax upper limit for value multiplicity, DcmVariableVM for unlimited
      *  @param vers standard version name, may be NULL
      *  @param doCopyStrings true if strings should be copied, false if only referenced
-     *  @param pcreator private creator name, may be NULL (for standard tags)
+     *  @param pcreator private creator identifier, may be NULL (for standard tags)
      */
     DcmDictEntry(Uint16 g, Uint16 e, DcmVR vr,
         const char* nam, int vmMin, int vmMax,
@@ -83,7 +84,7 @@ public:
      *  @param vmMax upper limit for value multiplicity, DcmVariableVM for unlimited
      *  @param vers standard version name, may be NULL
      *  @param doCopyStrings true if strings should be copied, false if only referenced
-     *  @param pcreator private creator name, may be NULL (for standard tags)
+     *  @param pcreator private creator identifier, may be NULL (for standard tags)
      */
     DcmDictEntry(Uint16 g, Uint16 e, Uint16 ug, Uint16 ue, DcmVR vr,
         const char* nam, int vmMin, int vmMax,
@@ -124,13 +125,13 @@ public:
         return tagName;
     }
 
-    /// returns private creator code, may be NULL
+    /// returns private creator identifier, may be NULL
     const char* getPrivateCreator() const
     {
         return privateCreator;
     }
 
-    /** checks if the private creator code equals the given string
+    /** checks if the private creator identifier equals the given string
      *  @param c string to compare with, may be NULL
      *  @return true if equal, false otherwise
      */
@@ -143,10 +144,10 @@ public:
       );
     }
 
-    /** checks if the private creator code of this object matches
-     *  the one of the given object.
+    /** checks if the private creator identifier of this object matches the one
+     *  of the given object.
      *  @param arg dictionary entry to compare with
-     *  @return true if private creators are equal, false otherwise
+     *  @return true if private creator identifiers are equal, false otherwise
      */
     int privateCreatorMatch(const DcmDictEntry& arg) const
     {
@@ -159,7 +160,8 @@ public:
         return valueMultiplicityMin;
     }
 
-    /// returns upper limit for VM (value multiplicity), DcmVariableVM for unlimited
+    /// returns upper limit for VM (value multiplicity), DcmVariableVM for
+    /// unlimited
     int getVMMax() const
     {
         return valueMultiplicityMax;
@@ -285,11 +287,12 @@ public:
 
     /* containment */
 
-    /** checks if the given tag key and private creator code are covered
+    /** checks if the given tag key and private creator identifier are covered
      *  by this object.
      *  @param key tag key
-     *  @param privCreator private creator, may be NULL
-     *  @return true if this entry contains the given tag for the given private creator
+     *  @param privCreator private creator identifier, may be NULL
+     *  @return true if this entry contains the given tag for the given private
+     *    creator identifier
      */
     int contains(const DcmTagKey& key, const char *privCreator) const /* this contains key */
     {
@@ -328,8 +331,8 @@ public:
 
     /* set relations */
 
-    /** checks if this entry describes a true subset of tag range
-     *  described by the given entry.
+    /** checks if this entry describes a true subset of tag range described by
+     *  the given entry.
      *  @param e entry to compare with
      *  @return true if this object is subset of e
      */
@@ -400,7 +403,7 @@ private:
     /// restriction (even, odd, unrestricted) for element range
     DcmDictRangeRestriction elementRangeRestriction;
 
-    /// private creator name, may be NULL
+    /// private creator identifier, may be NULL
     const char *privateCreator;
 };
 
