@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2018, OFFIS e.V.
+ *  Copyright (C) 1994-2024, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -27,6 +27,7 @@
 
 #include "dcmtk/dcmdata/dcobject.h"
 #include "dcmtk/ofstd/ofstring.h"
+#include "dcmtk/ofstd/oftypes.h"
 
 // forward declarations
 class DcmInputStreamFactory;
@@ -82,18 +83,18 @@ class DCMTK_DCMDATA_EXPORT DcmElement
      *  the object (if applicable).
      *  @param  rhs the right hand side of the comparison
      *  @return 0 if the object values are equal.
-     *          -1 if this element has fewer components than the rhs element.
-     *          Also -1 if the value of the first component that does not match
-     *          is lower in this object than in rhs. Also returned if rhs
-     *          cannot be casted to this object type or both objects are of
-     *          different VR (i.e. the DcmEVR returned by the element's ident()
-     *          call are different).
-     *          1 if either this element has more components than the rhs element, or
-     *          if the first component that does not match is greater in this object than
-     *          in rhs object.
-     *          If the function is overwritten by derived classes, the behaviour might
-     *          slightly change but all methods will return 0 on equality, and 1 or -1
-     *          if different.
+     *    -1 if this element has fewer components than the rhs element.
+     *    Also -1 if the value of the first component that does not match
+     *    is lower in this object than in rhs. Also returned if rhs
+     *    cannot be casted to this object type or both objects are of
+     *    different VR (i.e. the DcmEVR returned by the element's ident()
+     *    call are different).
+     *    1 if either this element has more components than the rhs element, or
+     *    if the first component that does not match is greater in this object
+     *    than in rhs object.
+     *    If the function is overwritten by derived classes, the behaviour might
+     *    slightly change but all methods will return 0 on equality, and 1 or -1
+     *    if different.
      */
     virtual int compare(const DcmElement& rhs) const =0;
 
@@ -111,15 +112,7 @@ class DCMTK_DCMDATA_EXPORT DcmElement
      */
     virtual OFCondition copyFrom(const DcmObject& rhs);
 
-    /** calculate the length of this DICOM element when encoded with the
-     *  given transfer syntax and the given encoding type for sequences.
-     *  For elements, the length includes the length of the tag, length field,
-     *  VR field and the value itself, for items and sequences it returns
-     *  the length of the complete item or sequence including delimitation tags
-     *  if applicable. Never returns undefined length.
-     *  @param xfer transfer syntax for length calculation
-     *  @param enctype sequence encoding type for length calculation
-     *  @return length of DICOM element
+    /** @copydoc DcmObject::calcElementLength()
      */
     virtual Uint32 calcElementLength(const E_TransferSyntax xfer,
                                      const E_EncodingType enctype);
@@ -131,8 +124,14 @@ class DCMTK_DCMDATA_EXPORT DcmElement
      *  @param enctype sequence encoding type for length calculation
      *  @return value length of DICOM element
      */
-    virtual Uint32 getLength(const E_TransferSyntax /*xfer*/ = EXS_LittleEndianImplicit,
-                             const E_EncodingType /*enctype*/ = EET_UndefinedLength)
+
+#ifdef DOXYGEN
+    virtual Uint32 getLength(const E_TransferSyntax xfer = EXS_LittleEndianImplicit,
+                             const E_EncodingType enctype = EET_UndefinedLength)
+#else
+    virtual Uint32 getLength(const E_TransferSyntax /* xfer */ = EXS_LittleEndianImplicit,
+                             const E_EncodingType /* enctype */ = EET_UndefinedLength)
+#endif
     {
         return getLengthField();
     }
@@ -145,6 +144,11 @@ class DCMTK_DCMDATA_EXPORT DcmElement
      */
     virtual OFBool isLeaf() const { return OFTrue; }
 
+    /** check if this element can be safely casted to DcmElement
+     *  @return true if DcmElement, false otherwise
+     */
+    virtual OFBool isElement() const { return OFTrue; }
+
     /** check if value of this element is loaded into main memory
      *  @return true if value is present in memory, false if value still resides in file
      */
@@ -312,6 +316,22 @@ class DCMTK_DCMDATA_EXPORT DcmElement
      */
     virtual OFCondition getFloat32(Float32 &val, const unsigned long pos = 0);
 
+    /** retrieve a single value of type Sint64. Requires element to be of corresponding VR,
+     *  otherwise an error is returned.
+     *  @param val value returned in this parameter upon success
+     *  @param pos position in multi-valued attribute, default 0
+     *  @return EC_Normal upon success, an error code otherwise
+     */
+    virtual OFCondition getSint64(Sint64 &val, const unsigned long pos = 0);
+
+    /** retrieve a single value of type Uint64. Requires element to be of corresponding VR,
+     *  otherwise an error is returned.
+     *  @param val value returned in this parameter upon success
+     *  @param pos position in multi-valued attribute, default 0
+     *  @return EC_Normal upon success, an error code otherwise
+     */
+    virtual OFCondition getUint64(Uint64 &val, const unsigned long pos = 0);
+
     /** retrieve a single value of type Float64. Requires element to be of corresponding VR,
      *  otherwise an error is returned.
      *  @param val value returned in this parameter upon success
@@ -433,6 +453,26 @@ class DCMTK_DCMDATA_EXPORT DcmElement
      */
     virtual OFCondition getFloat32Array(Float32 *&val);
 
+    /** get a pointer to the element value of the current element as type Sint64.
+     *  Requires element to be of corresponding VR, otherwise an error is returned.
+     *  This method does not copy, but returns a pointer to the element value,
+     *  which remains under control of this object and is valid only until the next
+     *  read, write or put operation.
+     *  @param val pointer to value returned in this parameter upon success
+     *  @return EC_Normal upon success, an error code otherwise
+     */
+    virtual OFCondition getSint64Array(Sint64 *&val);
+
+    /** get a pointer to the element value of the current element as type Uint64.
+     *  Requires element to be of corresponding VR, otherwise an error is returned.
+     *  This method does not copy, but returns a pointer to the element value,
+     *  which remains under control of this object and is valid only until the next
+     *  read, write or put operation.
+     *  @param val pointer to value returned in this parameter upon success
+     *  @return EC_Normal upon success, an error code otherwise
+     */
+    virtual OFCondition getUint64Array(Uint64 *&val);
+
     /** get a pointer to the element value of the current element as type Float64.
      *  Requires element to be of corresponding VR, otherwise an error is returned.
      *  This method does not copy, but returns a pointer to the element value,
@@ -640,7 +680,7 @@ class DCMTK_DCMDATA_EXPORT DcmElement
                                         E_ByteOrder byteOrder = gLocalByteOrder);
 
     /** create an empty Uint8 array of given number of bytes and set it.
-     *  All array elements are initialized with a value of 0 (using 'memzero').
+     *  All array elements are initialized with a value of 0 (using 'memset').
      *  This method is only applicable to certain VRs, e.g. OB.
      *  @param numBytes number of bytes (8 bit) to be created
      *  @param bytes stores the pointer to the resulting buffer
@@ -649,7 +689,7 @@ class DCMTK_DCMDATA_EXPORT DcmElement
     virtual OFCondition createUint8Array(const Uint32 numBytes, Uint8 *&bytes);
 
     /** create an empty Uint16 array of given number of words and set it.
-     *  All array elements are initialized with a value of 0 (using 'memzero').
+     *  All array elements are initialized with a value of 0 (using 'memset').
      *  This method is only applicable to OW data.
      *  @param numWords number of words (16 bit) to be created
      *  @param words stores the pointer to the resulting buffer
@@ -683,17 +723,22 @@ class DCMTK_DCMDATA_EXPORT DcmElement
      *  @param dataset dataset in which this pixel data element is contained
      *  @param frameSize frame size in bytes (without padding) returned in this
      *    parameter upon success, otherwise set to 0
+     *  @param pixelDataIsUncompressed flag indicating whether the frame
+     *    to be accessed already exists in uncompressed form. This is important
+     *    for the YBR_FULL_422 color model, which is never created by DCMTK's
+     *    decoders but can exist in uncompressed format
      *  @return EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition getUncompressedFrameSize(DcmItem *dataset,
-                                                 Uint32 &frameSize) const;
+                                                 Uint32 &frameSize,
+                                                 OFBool pixelDataIsUncompressed) const;
 
     /** access single frame without decompressing or loading a complete
      *  multi-frame object. The frame is copied into the buffer passed by the caller
      *  which must be large enough to contain a complete frame.
      *  @param dataset pointer to DICOM dataset in which this pixel data object is
      *    located. Used to access rows, columns, samples per pixel etc.
-     *  @param frameNo numer of frame, starting with 0 for the first frame.
+     *  @param frameNo number of frame, starting with 0 for the first frame.
      *  @param startFragment index of the compressed fragment that contains
      *    all or the first part of the compressed bitstream for the given frameNo.
      *    Upon successful return this parameter is updated to contain the index
@@ -772,14 +817,28 @@ class DCMTK_DCMDATA_EXPORT DcmElement
      *  @param candidateFirst the first part of the candidate that will be matched against this
      *    this element + keySecond.
      *  @param candidateSecond the second part of the candidate that will be combined with
-     *    candidateFirst for matching against this elemement + keySecond.
-     *  @return OFTrue if the combination of this elemement and keySecond match with the
+     *    candidateFirst for matching against this element + keySecond.
+     *  @return OFTrue if the combination of this element and keySecond match with the
      *    combination of candidateFirst and candidateSecond. OFFalse otherwise.
      */
     virtual OFBool combinationMatches(const DcmElement& keySecond,
                                       const DcmElement& candidateFirst,
                                       const DcmElement& candidateSecond) const;
 
+    /** returns a pointer to the input stream, if available, NULL otherwise.
+     *  In general, this pointer is available when the element is part of a dataset
+     *  that has been read from a DICOM file, the file is not encoded in deflate
+     *  transfer syntax, and the element value is large enough that loading the value
+     *  has been postponed to the first read access. The DcmInputStreamFactory object
+     *  can create an instance of a file stream seeked to the right position within
+     *  the DICOM file from where the element value can be read.
+     *  @return pointer to the input stream factory of the element, null if no object is available
+     */
+    inline const DcmInputStreamFactory* getInputStream() const
+    {
+        return fLoadValue;
+    }
+
     /* --- static helper functions --- */
 
     /** scan string value for conformance with given value representation (VR)
@@ -794,6 +853,16 @@ class DCMTK_DCMDATA_EXPORT DcmElement
                          const size_t pos = 0,
                          const size_t num = OFString_npos);
 
+    /** scan string value for conformance with given value representation (VR)
+     *  @param vr two-character identifier of the VR to be checked (lower case)
+     *  @param value string value to be scanned
+     *  @param size number of characters to be scanned in 'value'
+     *  @return numeric identifier of the VR found, 16 in case of unknown VR
+     */
+    static int scanValue(const OFString &vr,
+                         const char* const value,
+                         const size_t size);
+
     /** determine the number of values stored in a string, i.e.\ the value multiplicity (VM)
      *  @param str character string
      *  @param len length of the string (number of characters without the trailing NULL byte)
@@ -819,9 +888,9 @@ class DCMTK_DCMDATA_EXPORT DcmElement
      *  @param vmNum value multiplicity of the value to be checked.
      *    For empty values (vmNum=0), the status of the check is always EC_Normal (i.e. no error).
      *  @param vmStr value multiplicity (according to the data dictionary) to be checked for.
-     *    (valid values: "1", "1-2", "1-3", "1-8", "1-99", "1-n", "2", "2-n", "2-2n",
-     *                   "3", "3-n", "3-3n", "4", "5", "5-n", "6", "7", "7-7n", "8", "9",
-     *                   "16", "24", "32", "256")
+     *    (valid values: "1", "1-2", "1-3", "1-8", "1-99", "1-n", "2", "2-4", "2-n", "2-2n",
+     *                   "3", "3-n", "3-3n", "4", "4-5", "4-4n", "5", "5-n", "6", "6-n",
+     *                   "7", "7-7n", "8", "9", "11", "16", "24", "32", "256")
      *  @return status of the check, EC_ValueMultiplicityViolated in case of error
      */
     static OFCondition checkVM(const unsigned long vmNum,
@@ -830,7 +899,7 @@ class DCMTK_DCMDATA_EXPORT DcmElement
   protected:
 
     /** This function returns this element's value. The returned value corresponds to the
-    *   byte ordering (little or big endian) that was passed.
+     *   byte ordering (little or big endian) that was passed.
      *  @param newByteOrder The byte ordering that shall be accounted
      *                      for (little or big endian).
      */
