@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2015-2019, Open Connections GmbH
+ *  Copyright (C) 2015-2024, Open Connections GmbH
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation are maintained by
@@ -23,7 +23,13 @@
 #define IODMACRO_H
 
 #include "dcmtk/config/osconfig.h"
-#include "dcmtk/dcmdata/dctk.h" // For VR classes, i.e. DcmCodeString etc.
+#include "dcmtk/dcmdata/dcdeftag.h"
+#include "dcmtk/dcmdata/dcvrlo.h"
+#include "dcmtk/dcmdata/dcvris.h"
+#include "dcmtk/dcmdata/dcvrus.h"
+#include "dcmtk/dcmdata/dcvrlt.h"
+#include "dcmtk/dcmdata/dcvrcs.h"
+#include "dcmtk/dcmdata/dcvrpn.h"
 #include "dcmtk/dcmiod/iodrules.h"
 #include "dcmtk/dcmiod/modbase.h"
 #include "dcmtk/ofstd/ofstring.h"
@@ -683,7 +689,7 @@ public:
     virtual OFCondition getReferencedSegmentNumber(OFVector<Uint16>& values);
 
     /** Set Referenced Frame Number
-     *  @param  values The frame numbers that shoule be referenced
+     *  @param  values The frame numbers that should be referenced
      *  @param  checkValue  If OFTrue (default) the given values will be checked
      *  @return EC_Normal if successful, error otherwise
      */
