@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2012-2017, OFFIS e.V.
+ *  Copyright (C) 2012-2022, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -28,6 +28,8 @@
 #include "dcmtk/dcmnet/dimse.h"
 #include "dcmtk/ofstd/ofmem.h"      /* For OFshared_ptr */
 
+class DcmTransportLayer;
+
 /** Class that encapsulates an SCP configuration that is needed in order to
  *  configure the service negotiation behavior (presentation contexts, AE
  *  title, listening port, etc) as well as some runtime configuration like
@@ -87,7 +89,10 @@ public:
 
   /** Set SCP's TCP/IP listening port
    *  @param port [in] The port number to listen on. Note that usually on Unix-like systems
-   *                   only root user is permitted to open ports below 1024.
+   *                   only root user is permitted to open ports below 1024. Port number 0
+   *                   can be used to let the OS assign an available free port. In that case,
+   *                   the class using this SCP configuration should update the actual port
+   *                   using setPort() once it is known.
    */
   void setPort(const Uint16 port);
 
@@ -223,7 +228,7 @@ public:
 
   /* Get methods for SCP settings */
 
-  /** Returns TCP/IP port number SCP listens for new connection requests
+  /** Returns TCP/IP port number SCP listens for new connection requests.
    *  @return The port number
    */
   Uint16 getPort() const;
@@ -296,6 +301,23 @@ public:
    */
   OFBool getProgressNotificationMode() const;
 
+  /** Returns true if an external transport layer (e.g. TLS) is enabled,
+   *  false if the default, transparent layer is used.
+   *  @return true if an external transport layer is enabled
+   */
+  OFBool transportLayerEnabled() const;
+
+  /** Returns pointer to the transport layer object in use
+   *  @return pointer to the transport layer object in use, may be NULL.
+   */
+  DcmTransportLayer * getTransportLayer() const;
+
+  /** set an explicit transport layer (e.g. for TLS communication) to use
+   *  @param tlayer [in] The transport layer object.
+   *                     This function does not take ownership of tlayer.
+   */
+  void setTransportLayer(DcmTransportLayer *tlayer);
+
   /** Dump presentation contexts to given output stream, useful for debugging.
    *  @param out [out] The output stream
    *  @param profileName [in] The profile to dump. If empty (default), the currently
@@ -393,6 +415,10 @@ protected:
 
   /// Progress notification mode (default: OFTrue)
   OFBool m_progressNotificationMode;
+
+  /// The transport layer in use for communication (e.g. for TLS).
+  /// Default is NULL for the normal TCP layer.
+  DcmTransportLayer *m_tLayer; /// Doesn't have ownership
 };
 
 /** Enables sharing configurations by multiple DcmSCPs.
@@ -411,7 +437,7 @@ struct DCMTK_DCMNET_EXPORT DcmSharedSCPConfig : private OFshared_ptr<DcmSCPConfi
 
   /** Copy construct a DcmSharedSCPConfig object from a DcmSCPConfig object.
    *  This constructor enables sharing of an already existing DcmSCPConfig object
-   *  by copy constructing a sharable configuration object from it.
+   *  by copy constructing a shareable configuration object from it.
    *  @param config the DcmSCPConfig object to copy construct the DcmSharedSCPConfig
    *    object from.
    */
