@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2017, J. Riesmeier, Oldenburg, Germany
+ *  Copyright (C) 2017-2022, J. Riesmeier, Oldenburg, Germany
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  Header file for class TID1501_MeasurementGroup
@@ -19,11 +19,12 @@
 
 #include "dcmtk/dcmsr/cmr/define.h"
 #include "dcmtk/dcmsr/cmr/tid300.h"
+#include "dcmtk/dcmsr/cmr/cid218e.h"
 #include "dcmtk/dcmsr/cmr/cid244e.h"
 #include "dcmtk/dcmsr/cmr/cid6147.h"
 #include "dcmtk/dcmsr/cmr/cid7181.h"
 #include "dcmtk/dcmsr/cmr/cid7464.h"
-#include "dcmtk/dcmsr/cmr/cid7469.h"
+#include "dcmtk/dcmsr/cmr/cid7551.h"
 
 
 // include this file in doxygen documentation
@@ -44,12 +45,14 @@
  *  @tparam  T_Units        units of the numeric measurement values (context group)
  *  @tparam  T_Method       methods used for measuring the values (context group)
  *  @tparam  T_Derivation   methods of deriving or calculating the values (context group)
+ *  @tparam  T_Purpose      purpose of reference for the source of measurement (context group)
  *  @note Please note that this template class requires explicit instantiation for those
  *        combinations of the template parameters that are actually used.  This is
  *        because the implementation is "hidden" in a separate source file, which has
  *        some advantages over the usual header-only approach.
  */
-template<typename T_Measurement, typename T_Units, typename T_Method, typename T_Derivation>
+template<typename T_Measurement, typename T_Units, typename T_Method, typename T_Derivation,
+    typename T_Purpose>
 class DCMTK_CMR_EXPORT TID1501_MeasurementGroup
   : public DSRSubTemplate
 {
@@ -59,10 +62,11 @@ class DCMTK_CMR_EXPORT TID1501_MeasurementGroup
     // type definitions
     typedef CMR_SRNumericMeasurementValueWithUnits<T_Units> MeasurementValue;
 
-    typedef ::TID300_Measurement<CID7469_GenericIntensityAndSizeMeasurements,
-                                 CID7181_AbstractMultiDimensionalImageModelComponentUnits,
+    typedef ::TID300_Measurement<CID218e_QuantitativeImageFeature,
+                                 CID7181_AbstractMultiDimensionalImageModelComponentUnit,
                                  CID6147_ResponseCriteria,
-                                 CID7464_GeneralRegionOfInterestMeasurementModifiers>
+                                 CID7464_GeneralRegionOfInterestMeasurementModifier,
+                                 CID7551_GenericPurposeOfReferenceToImagesAndCoordinatesInMeasurement>
             TID300_Measurement;
 
     /** (default) constructor
@@ -78,9 +82,8 @@ class DCMTK_CMR_EXPORT TID1501_MeasurementGroup
 
     /** check whether the current internal state is valid.
      *  That means, whether the base class is valid and whether all mandatory content
-     *  items and included templates are valid (present), i.e. hasMeasurementGroup(),
-     *  hasTrackingIdentifier(), hasTrackingUniqueIdentifier() and hasMeasurements()
-     *  return true.
+     *  items and included templates are valid (present), i.e. hasMeasurementGroup()
+     *  and hasMeasurements() return true.
      ** @return OFTrue if valid, OFFalse otherwise
      */
     OFBool isValid() const;
@@ -99,21 +102,22 @@ class DCMTK_CMR_EXPORT TID1501_MeasurementGroup
     OFBool hasMeasurementGroup(const OFBool checkChildren = OFFalse) const;
 
     /** check whether the 'Tracking Identifier' content item (TID 1501 - Row 2) is
-     *  present.  This content item is mandatory, i.e. should be present with a value.
+     *  present.  This content item is optional, i.e. might be absent.
      ** @return OFTrue if the tracking identifier is present, OFFalse otherwise
      */
     OFBool hasTrackingIdentifier() const;
 
     /** check whether the 'Tracking Unique Identifier' content item (TID 1501 - Row 3) is
-     *  present.  This content item is mandatory, i.e. should be present with a value.
+     *  present.  This content item is optional, i.e. might be absent.
      ** @return OFTrue if the tracking unique identifier is present, OFFalse otherwise
      */
     OFBool hasTrackingUniqueIdentifier() const;
 
     /** check whether there is an included 'Measurement' template (TID 1501 - Row 10) in
-     *  this measurement template.  Initially, this mandatory sub-template is created and
-     *  included by the constructor of this class.  After clear() has been called, the
-     *  content item has to be recreated, which is done automatically when needed.
+     *  this measurement template.  Initially, the mandatory sub-template TID 300 is
+     *  created and included by the constructor of this class.  After clear() has been
+     *  called, the content item has to be recreated, which is done automatically when
+     *  needed.
      ** @param  checkChildren  flag, which is enabled by default, indicating whether to
      *                         check for any children, i.e.\ whether the respective
      *                         sub-template has any content (child nodes).  If OFFalse,
