@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2016, OFFIS e.V.
+ *  Copyright (C) 2000-2024, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -33,6 +33,13 @@
 #include "dcmtk/dcmdata/dcvrul.h"
 
 
+// include this file in doxygen documentation
+
+/** @file dsrnumvl.h
+ *  @brief definitions for class DSRNumericMeasurementValue
+ */
+
+
 /*---------------------*
  *  class declaration  *
  *---------------------*/
@@ -62,10 +69,10 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
                                const OFBool check = OFTrue);
 
     /** constructor
-     ** @param  valueQualifier  code representing the numeric value qualifier.  Used to
-     *                          specify the reason for the absence of the measured value
-     *                          sequence, i.e. why the numeric value and measurement unit
-     *                          are empty.
+     ** @param  valueQualifier  code representing the numeric value qualifier (mandatory).
+     *                          Used to specify the reason for the absence of the measured
+     *                          value sequence, i.e. why the numeric value and measurement
+     *                          unit are empty.
      *  @param  check           if enabled, check value for validity before setting it.
      *                          See corresponding setValue() method for details.
      */
@@ -75,10 +82,7 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
     /** constructor
      ** @param  numericValue     numeric value (VR=DS, mandatory)
      *  @param  measurementUnit  code representing the units of measurement (mandatory)
-     *  @param  valueQualifier   code representing the numeric value qualifier (optional).
-     *                           Can also be used to specify the reason for the absence of
-     *                           the measured value sequence (where 'numericValue' and
-     *                           'measurementUnit' are stored).
+     *  @param  valueQualifier   code representing the numeric value qualifier (optional)
      *  @param  check            if enabled, check values for validity before setting them.
      *                           See corresponding setValue() method for details.
      */
@@ -107,6 +111,25 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
      */
     virtual void clear();
 
+    /** check whether values are "equal".
+     *  Two numeric measurement values are equal if the numeric value, the measurement unit
+     *  and the value qualifier are equal.  Other (additional) information is not used.
+     ** @param  numericMeasurement  numeric measurement value that should be compared to the
+     *                              current one
+     ** @return OFTrue if both numeric measurement values are equal, OFFalse otherwise
+     */
+    OFBool isEqual(const DSRNumericMeasurementValue &numericMeasurement) const;
+
+    /** check whether values are "not equal".
+     *  Two numeric measurement values are not equal if either the numeric value or the
+     *  measurement unit or the value qualifier are not equal.  Other (additional) information
+     *  is not used for comparison.
+     ** @param  numericMeasurement  numeric measurement value that should be compared to the
+     *                              current one
+     ** @return OFTrue if both numeric measurement values are not equal, OFFalse otherwise
+     */
+    OFBool isNotEqual(const DSRNumericMeasurementValue &numericMeasurement) const;
+
     /** check whether the current numeric measurement value is valid.
      *  The value is valid if isEmpty() is true or both the numeric value and the measurement
      *  unit contain a valid value, and the value qualifier is valid (see checkXXX() methods).
@@ -177,7 +200,7 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
 
     /** write measured value sequence and numeric value qualifier code sequence to dataset.
      *  The measured value sequence is always written (might be empty, though).  The numeric
-     *  value qualifier code sequence is optional and, therefore, only written if non-empty.
+     *  value qualifier code sequence is conditional and, therefore, only written if non-empty.
      ** @param  dataset  DICOM dataset to which the sequences should be written
      ** @return status, EC_Normal if successful, an error code otherwise
      */
@@ -187,7 +210,8 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
      ** @param  docStream    output stream to which the main HTML/XHTML document is written
      *  @param  annexStream  output stream to which the HTML/XHTML document annex is written
      *  @param  annexNumber  reference to the variable where the current annex number is stored.
-     *                       Value is increased automatically by 1 after a new entry has been added.
+     *                       Value is increased automatically by 1 after a new entry has been
+     *                       added.
      *  @param  flags        flag used to customize the output (see DSRTypes::HF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
@@ -226,7 +250,7 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
         return MeasurementUnit;
     }
 
-    /** get numeric value qualifier (optional)
+    /** get numeric value qualifier (conditional)
      ** @return reference to current numeric value qualifier code (might be invalid or empty)
      */
     inline const DSRCodedEntryValue &getNumericValueQualifier() const
@@ -240,8 +264,7 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
      */
     OFCondition getMeasurementUnit(DSRCodedEntryValue &measurementUnit) const;
 
-    /** get copy of numeric value qualifier (optional).
-     *  Can be used to specify the reason for the absence of the measured value sequence.
+    /** get copy of numeric value qualifier (conditional)
      ** @param  valueQualifier  reference to variable in which the code should be stored
      ** @return always returns EC_Normal
      */
@@ -297,8 +320,8 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
     /** set empty numeric value and measurement unit with a numeric value qualifier.
      *  Before setting the value, it is usually checked.  If the value is invalid, the
      *  current numeric measurement value is not replaced and remains unchanged.
-     ** @param  valueQualifier  numeric value qualifier to be set.  Used to specify the
-     *                          reason for the absence of the measured value sequence,
+     ** @param  valueQualifier  numeric value qualifier to be set.  Shall be used to specify
+     *                          the reason for the absence of the measured value sequence,
      *                          i.e. why the numeric value and measurement unit are empty.
      *  @param  check           if enabled, check value for validity before setting it.
      *                          See checkNumericValueQualifier() method for details.
@@ -316,10 +339,8 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
      *  needed.
      ** @param  numericValue     numeric value to be set (VR=DS, mandatory)
      *  @param  measurementUnit  measurement unit to be set (mandatory)
-     *  @param  valueQualifier   numeric value qualifier to be set (optional).  Can also be
-     *                           used to specify the reason for the absence of the measured
-     *                           value sequence (where 'numericValue' and 'measurementUnit'
-     *                           are stored).  Use an empty code to remove the current value.
+     *  @param  valueQualifier   numeric value qualifier to be set (optional).
+     *                           Use an empty code to remove the current value.
      *  @param  check            if enabled, check values for validity before setting them.
      *                           See checkXXX() methods for details.
      ** @return status, EC_Normal if successful, an error code otherwise
@@ -391,12 +412,12 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
                                    const OFBool check = OFTrue);
 
     /** set numeric value qualifier.
-     *  This optional code specifies the qualification of the Numeric Value in the Measured
+     *  This conditional code specifies the qualification of the Numeric Value in the Measured
      *  Value Sequence, or the reason for the absence of the Measured Value Sequence Item.
      *  Before setting the code, it is usually checked.  If the code is invalid the current
      *  code is not replaced and remains unchanged.
-     ** @param  valueQualifier  numeric value qualifier to be set (optional).  Use an empty
-     *                          code to remove the current value.
+     ** @param  valueQualifier  numeric value qualifier to be set (conditional).
+     *                          Use an empty code to remove the current value.
      *  @param  check           if enabled, check value for validity before setting it.
      *                          See checkNumericValueQualifier() method for details.
      ** @return status, EC_Normal if successful, an error code otherwise
@@ -520,7 +541,7 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
     OFString               NumericValue;
     /// Measurement Unit (type 1 within a type 2 sequence)
     DSRCodedEntryValue     MeasurementUnit;
-    /// Numeric Value Qualifier (type 3)
+    /// Numeric Value Qualifier (type 1C)
     DSRCodedEntryValue     ValueQualifier;
     /// Floating Point Value (VR=FD, type 1C)
     DcmFloatingPointDouble FloatingPointValue;
@@ -531,6 +552,10 @@ class DCMTK_DCMSR_EXPORT DSRNumericMeasurementValue
 };
 
 
+/*------------------------*
+ *  i/o stream operators  *
+ *------------------------*/
+
 /** output stream operator for numeric measurement values.
  *  Internally, the DSRNumericMeasurementValue::print() method is used, i.e. the output
  *  looks like this: "3.5" (cm,UCUM[1.4],"centimeter") or "empty" (if the value is empty)
@@ -543,4 +568,27 @@ DCMTK_DCMSR_EXPORT STD_NAMESPACE ostream &operator<<(STD_NAMESPACE ostream &stre
                                                      const DSRNumericMeasurementValue &numericMeasurement);
 
 
+/*------------------------*
+ *  comparison operators  *
+ *------------------------*/
+
+/** equality operator.
+ *  Internally, the DSRNumericMeasurementValue::isEqual() method is used.
+ *  @param  lhs  left-hand side
+ *  @param  rhs  right-hand side
+ *  @return OFTrue if 'lhs' and 'rhs' are equal, OFFalse otherwise
+ */
+DCMTK_DCMSR_EXPORT OFBool operator==(const DSRNumericMeasurementValue &lhs,
+                                     const DSRNumericMeasurementValue &rhs);
+
+/** inequality operator.
+ *  Internally, the DSRNumericMeasurementValue::isNotEqual() method is used.
+ *  @param  lhs  left-hand side
+ *  @param  rhs  right-hand side
+ *  @return OFTrue if 'lhs' and 'rhs' are not equal, OFFalse otherwise
+ */
+DCMTK_DCMSR_EXPORT OFBool operator!=(const DSRNumericMeasurementValue &lhs,
+                                     const DSRNumericMeasurementValue &rhs);
+
+
 #endif
