@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2021, OFFIS e.V.
+ *  Copyright (C) 2000-2024, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -31,6 +31,13 @@
 #include "dcmtk/dcmsr/dsrwavch.h"
 
 
+// include this file in doxygen documentation
+
+/** @file dsrwavvl.h
+ *  @brief definitions for class DSRWaveformReferenceValue
+ */
+
+
 /*---------------------*
  *  class declaration  *
  *---------------------*/
@@ -77,23 +84,23 @@ class DCMTK_DCMSR_EXPORT DSRWaveformReferenceValue
      */
     DSRWaveformReferenceValue &operator=(const DSRWaveformReferenceValue &referenceValue);
 
-    /** comparison operator "equal"
-     ** @param  referenceValue  waveform reference value that should be compared to the current one
-     ** @return OFTrue if both waveform reference values are equal, OFFalse otherwise
-     */
-    OFBool operator==(const DSRWaveformReferenceValue &referenceValue) const;
-
-    /** comparison operator "not equal"
-     ** @param  referenceValue  waveform reference value that should be compared to the current one
-     ** @return OFTrue if both waveform reference values are not equal, OFFalse otherwise
-     */
-    OFBool operator!=(const DSRWaveformReferenceValue &referenceValue) const;
-
     /** clear all internal variables.
      *  Since an empty waveform reference is invalid the reference becomes invalid afterwards.
      */
     virtual void clear();
 
+    /** check whether values are "equal"
+     ** @param  referenceValue  waveform reference value that should be compared to the current one
+     ** @return OFTrue if both waveform reference values are equal, OFFalse otherwise
+     */
+    OFBool isEqual(const DSRWaveformReferenceValue &referenceValue) const;
+
+    /** check whether values are "not equal"
+     ** @param  referenceValue  waveform reference value that should be compared to the current one
+     ** @return OFTrue if both waveform reference values are not equal, OFFalse otherwise
+     */
+    OFBool isNotEqual(const DSRWaveformReferenceValue &referenceValue) const;
+
     /** check whether the content is short.
      *  This method is used to check whether the rendered output of this content item can be
      *  expanded inline or not (used for renderHTML()).
@@ -137,12 +144,14 @@ class DCMTK_DCMSR_EXPORT DSRWaveformReferenceValue
      *  @param  annexNumber  reference to the variable where the current annex number is stored.
      *                       Value is increased automatically by 1 after a new entry has been added.
      *  @param  flags        flag used to customize the output (see DSRTypes::HF_xxx)
+     *  @param  urlPrefix    optional URL prefix used for hyperlink to referenced composite object
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition renderHTML(STD_NAMESPACE ostream &docStream,
                                    STD_NAMESPACE ostream &annexStream,
                                    size_t &annexNumber,
-                                   const size_t flags) const;
+                                   const size_t flags,
+                                   const char *urlPrefix = NULL) const;
 
     /** get reference to waveform reference value
      ** @return reference to waveform reference value
@@ -216,7 +225,7 @@ class DCMTK_DCMSR_EXPORT DSRWaveformReferenceValue
     /** check the specified SOP class UID for validity.
      *  This method further specializes the checks performed in the base class
      *  DSRCompositeReferenceValue.  All waveform SOP classes that are defined
-     *  in DICOM PS 3.6-2020c are allowed.
+     *  in DICOM PS 3.6-2023c are allowed.
      ** @param  sopClassUID     SOP class UID to be checked
      *  @param  reportWarnings  if enabled, report warning messages to the logger
      ** @return status, EC_Normal if value is valid, an error code otherwise
@@ -232,4 +241,27 @@ class DCMTK_DCMSR_EXPORT DSRWaveformReferenceValue
 };
 
 
+/*------------------------*
+ *  comparison operators  *
+ *------------------------*/
+
+/** equality operator.
+ *  Internally, the DSRWaveformReferenceValue::isEqual() method is used.
+ *  @param  lhs  left-hand side
+ *  @param  rhs  right-hand side
+ *  @return OFTrue if 'lhs' and 'rhs' are equal, OFFalse otherwise
+ */
+DCMTK_DCMSR_EXPORT OFBool operator==(const DSRWaveformReferenceValue &lhs,
+                                     const DSRWaveformReferenceValue &rhs);
+
+/** inequality operator.
+ *  Internally, the DSRWaveformReferenceValue::isNotEqual() method is used.
+ *  @param  lhs  left-hand side
+ *  @param  rhs  right-hand side
+ *  @return OFTrue if 'lhs' and 'rhs' are not equal, OFFalse otherwise
+ */
+DCMTK_DCMSR_EXPORT OFBool operator!=(const DSRWaveformReferenceValue &lhs,
+                                     const DSRWaveformReferenceValue &rhs);
+
+
 #endif
