@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2003-2021, OFFIS e.V.
+ *  Copyright (C) 2003-2024, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -39,18 +39,6 @@
 #define LIBXML_ATTR_FORMAT(fmt,args)
 #endif
 
-// The libxml library also uses unicode. So we have to reuse some
-// workarounds for the ICU library here as well.
-// The type char16_t is only supported since C++11.
-#ifndef HAVE_CHAR16_T
-#define UCHAR_TYPE uint16_t
-#endif
-
-//If U_NOEXCEPT is not defined, ICU falls back to NOEXCEPT.
-#ifndef HAVE_CXX11
-#define U_NOEXCEPT
-#endif
-
 #include <libxml/parser.h>
 #endif
 
