@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2001-2021, OFFIS e.V.
+ *  Copyright (C) 2001-2023, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -28,6 +28,7 @@
 #include "dcmtk/ofstd/oftypes.h"    /* for class OFBool */
 #include "dcmtk/ofstd/ofstring.h"   /* for class OFString */
 #include "dcmtk/ofstd/ofcast.h"
+#include "dcmtk/ofstd/ofdiag.h"
 #include <cstring>
 #include <cstdlib>                  /* for free() */
 
@@ -140,9 +141,20 @@ extern DCMTK_OFSTD_EXPORT const unsigned short EC_CODE_CannotCloseEncoding;
 extern DCMTK_OFSTD_EXPORT const unsigned short EC_CODE_CannotConvertEncoding;
 /// status code constant: error, cannot control character encoding converter
 extern DCMTK_OFSTD_EXPORT const unsigned short EC_CODE_CannotControlConverter;
-
 /// status code constant: error, cannot create directory
 extern DCMTK_OFSTD_EXPORT const unsigned short EC_CODE_CannotCreateDirectory;
+
+/// condition constant: error, IPC message queue already initialized
+extern DCMTK_OFSTD_EXPORT const OFConditionConst EC_IPCMessageQueueExists;
+/// condition constant: error, IPC message queue not initialized
+extern DCMTK_OFSTD_EXPORT const OFConditionConst EC_IPCMessageNoQueue;
+/// condition constant: error, IPC message queue operation failed
+extern DCMTK_OFSTD_EXPORT const OFConditionConst EC_IPCMessageQueueFailure;
+/// condition constant: error, IPC message queue empty
+extern DCMTK_OFSTD_EXPORT const OFConditionConst EC_IPCMessageQueueEmpty;
+/// condition constant: error, IPC message empty (zero length)
+extern DCMTK_OFSTD_EXPORT const OFConditionConst EC_IPCEmptyMessage;
+
 //@}
 
 
@@ -211,6 +223,11 @@ public:
     }
   }
 
+// suppress spurious gcc 12 warning about use-after-free.
+// this is a known bug in gcc.
+#include DCMTK_DIAGNOSTIC_PUSH
+#include DCMTK_DIAGNOSTIC_IGNORE_USE_AFTER_FREE
+
   /// destructor
   ~OFCondition()
   {
@@ -220,6 +237,8 @@ public:
     }
   }
 
+#include DCMTK_DIAGNOSTIC_POP
+
   /** copy assignment operator
    *  @param arg The OFCondition instance to copy
    *  @return *this
