@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2006-2017, OFFIS e.V.
+ *  Copyright (C) 2006-2024, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -24,18 +24,13 @@
 #define OFFILE_H
 
 #include "dcmtk/config/osconfig.h"
-
 #include "dcmtk/ofstd/oftypes.h"    /* for class OFBool */
 #include "dcmtk/ofstd/ofstring.h"   /* for class OFString */
 #include "dcmtk/ofstd/ofstd.h"      /* for class OFStandard */
 
-#define INCLUDE_UNISTD
-#define INCLUDE_CSTDIO
-#define INCLUDE_CSTRING
-#define INCLUDE_CSTDARG
-#define INCLUDE_CERRNO
-//#define INCLUDE_CWCHAR    /* not yet implemented in "ofstdinc.h" */
-#include "dcmtk/ofstd/ofstdinc.h"
+#include <cstdio>
+#include <cstdlib>
+#include <cerrno>
 
 BEGIN_EXTERN_C
 #ifdef HAVE_SYS_STAT_H
@@ -113,6 +108,9 @@ typedef fpos_t offile_fpos_t;
 typedef int offile_errno_t;
 
 
+// forward declarations
+class OFpath;
+
 /** class for managing filenames consisting either of conventional (8-bit) or
  *  wide (e.g.\ 16-bit) characters.  The wide character support is currently
  *  Windows-specific because most other operating systems use UTF-8, which is
@@ -128,7 +126,7 @@ public:
   /** constructor expecting a conventional character string
    *  @param filename filename to be stored (8-bit characters, e.g. UTF-8)
    *  @param convert  convert given filename to wide character encoding as an
-   *    alternative representation
+   *    alternative representation.  Only works on Windows systems.
    */
   OFFilename(const char *filename,
              const OFBool convert = OFFalse);
@@ -141,8 +139,20 @@ public:
   OFFilename(const OFString &filename,
              const OFBool convert = OFFalse);
 
+  /** constructor expecting an OFpath instance
+   *  @param path    OFpath instance storing a filename in native format
+   *    (currently, identical to an 8-bit character string)
+   *  @param convert convert given filename to wide character encoding as an
+   *    alternative representation.  Only works on Windows systems.
+   */
+  OFFilename(const OFpath &path,
+             const OFBool convert = OFFalse);
+
 #if (defined(WIDE_CHAR_FILE_IO_FUNCTIONS) || defined(WIDE_CHAR_MAIN_FUNCTION)) && defined(_WIN32)
   /** constructor expecting a wide character string
+   *  @remark This constructor is only available if DCMTK is compiled on Windows
+   *    Operating Systems with wide chars enabled (defining _WIN32 as well as
+   *    WIDE_CHAR_FILE_IO_FUNCTIONS or WIDE_CHAR_MAIN_FUNCTION).
    *  @param filename filename to be stored (e.g. 16-bit characters)
    *  @param convert  convert given filename to UTF-8 encoding as an
    *    alternative representation.  Only works on Windows systems.
@@ -176,12 +186,12 @@ public:
    */
   void swap(OFFilename &arg);
 
-  /** checks whether this object stores an empty filename
+  /** check whether this object stores an empty filename
    *  @return OFTrue if the filename is empty, OFFalse otherwise
    */
   OFBool isEmpty() const;
 
-  /** checks whether this object stores a wide character filename
+  /** check whether this object stores a wide character filename
    *  @return OFTrue if the filename uses wide characters, OFFalse otherwise
    */
   inline OFBool usesWideChars() const
@@ -203,6 +213,9 @@ public:
 
 #if (defined(WIDE_CHAR_FILE_IO_FUNCTIONS) || defined(WIDE_CHAR_MAIN_FUNCTION)) && defined(_WIN32)
   /** get stored filename consisting of wide characters
+   *  @remark This method is only available if DCMTK is compiled on Windows
+   *    Operating Systems with wide chars enabled (defining _WIN32 as well as
+   *    WIDE_CHAR_FILE_IO_FUNCTIONS or WIDE_CHAR_MAIN_FUNCTION).
    *  @return wide char filename (might be NULL if none is stored)
    */
   inline const wchar_t *getWideCharPointer() const
@@ -211,6 +224,26 @@ public:
   }
 #endif
 
+  /** check whether the standard input or output streams should be used by
+   *  comparing the filename with "-"
+   *  @return OFTrue if stdin or stdout should be used, OFFalse otherwise
+   */
+  OFBool isStandardStream() const
+  {
+    OFBool result = OFFalse;
+#if defined(WIDE_CHAR_FILE_IO_FUNCTONS) && defined(_WIN32)
+    if (usesWideChars())
+    {
+        result = (wcscmp(getWideCharPointer(), L"-") == 0);
+    } else
+#endif
+    if (getCharPointer() != NULL)
+    {
+        result = (strcmp(getCharPointer(), "-") == 0);
+    }
+    return result;
+  }
+
   /** replace currently stored filename by given value
    *  @param filename filename to be stored (8-bit characters, e.g. UTF-8)
    *  @param convert  convert given filename to wide character encoding as an
@@ -227,8 +260,20 @@ public:
   void set(const OFString &filename,
            const OFBool convert = OFFalse);
 
+  /** replace currently stored filename by given value
+   *  @param OFpath  OFpath instance storing a filename in native format
+   *    (currently, identical to an 8-bit character string)
+   *  @param convert convert given filename to wide character encoding as an
+   *    alternative representation).  Only works on Windows systems.
+   */
+  void set(const OFpath &path,
+           const OFBool convert = OFFalse);
+
 #if (defined(WIDE_CHAR_FILE_IO_FUNCTIONS) || defined(WIDE_CHAR_MAIN_FUNCTION)) && defined(_WIN32)
   /** replace currently stored filename by given value
+   *  @remark This method is only available if DCMTK is compiled on Windows
+   *    Operating Systems with wide chars enabled (defining _WIN32 as well as
+   *    WIDE_CHAR_FILE_IO_FUNCTIONS or WIDE_CHAR_MAIN_FUNCTION).
    *  @param filename filename to be stored (e.g. 16-bit characters)
    *  @param convert  convert given filename to UTF-8 encoding as an alternative
    *    representation.  Only works on Windows systems.
@@ -238,10 +283,13 @@ public:
 #endif
 
 private:
-  /// filename consisting of conventional characters (8-bit, e.g. UTF-8)
+  /// filename consisting of conventional characters (8-bit, e.g.\ UTF-8)
   char *filename_;
 #if (defined(WIDE_CHAR_FILE_IO_FUNCTIONS) || defined(WIDE_CHAR_MAIN_FUNCTION)) && defined(_WIN32)
   /// filename consisting of wide characters (e.g. 16-bit on Windows)
+  /// @remark This member is only available if DCMTK is compiled on Windows
+  ///   Operating Systems with wide chars enabled (defining _WIN32 as well as
+  ///   WIDE_CHAR_FILE_IO_FUNCTIONS or WIDE_CHAR_MAIN_FUNCTION).
   wchar_t *wfilename_;
 #endif
 };
@@ -279,7 +327,7 @@ DCMTK_OFSTD_EXPORT STD_NAMESPACE ostream &operator<<(STD_NAMESPACE ostream &stre
  *  on Unix platforms are based on errno and strerror/strerror_r, but may be based
  *  on other mechanisms on platforms where errno does not exist.
  */
-class OFFile
+class DCMTK_OFSTD_EXPORT OFFile
 {
 public:
   /// default constructor, creates an object that is not associated with any file.
@@ -309,7 +357,7 @@ public:
 #ifdef EXPLICIT_LFS_64
     file_ = :: fopen64(filename, modes);
 #else
-    file_ = STDIO_NAMESPACE fopen(filename, modes);
+    file_ = :: fopen(filename, modes);
 #endif
     if (file_) popened_ = OFFalse; else storeLastError();
     return (file_ != NULL);
@@ -317,8 +365,10 @@ public:
 
 #if defined(WIDE_CHAR_FILE_IO_FUNCTIONS) && defined(_WIN32)
   /** opens the file whose name is the wide character string pointed to by path and
-   *  associates a stream with it. This function is Win32 specific and only exists on
-   *  WinNT and newer.
+   *  associates a stream with it.
+   *  @remark This member is only available if DCMTK is compiled on Windows
+   *    Operating Systems with wide chars enabled (defining _WIN32 as well as
+   *    WIDE_CHAR_FILE_IO_FUNCTIONS).
    *  @param filename Unicode filename path to file
    *  @param modes "r", "w" or "a" with possible modifiers "+", "b", as a wide
    *    character string
@@ -396,17 +446,7 @@ public:
    *  @param modes "r" or "w"
    *  @return true if pipe was successfully created, false otherwise
    */
-  OFBool popen(const char *command, const char *modes)
-  {
-    if (file_) fclose();
-#ifdef HAVE_POPEN
-    file_ = :: popen(command, modes);
-#else
-    file_ = _popen(command, modes);
-#endif
-    if (file_) popened_ = OFTrue; else storeLastError();
-    return (file_ != NULL);
-  }
+  OFBool popen(const char *command, const char *modes);
 
   /** opens the file whose name is the string pointed to by path and associates
    *  the stream pointed maintained by this object with it. The original stream
@@ -424,7 +464,7 @@ public:
     // MinGW has EXPLICIT_LFS_64 but no freopen64()
     file_ = :: freopen64(filename, modes, file_);
 #else
-    file_ = STDIO_NAMESPACE freopen(filename, modes, file_);
+    file_ = :: freopen(filename, modes, file_);
 #endif
     if (file_) popened_ = OFFalse; else storeLastError();
     return (file_ != NULL);
@@ -443,7 +483,7 @@ public:
     // MinGW has EXPLICIT_LFS_64 but no tmpfile64()
     file_ = :: tmpfile64();
 #else
-    file_ = STDIO_NAMESPACE tmpfile();
+    file_ = :: tmpfile();
 #endif
     if (file_) popened_ = OFFalse; else storeLastError();
     return (file_ != NULL);
@@ -456,29 +496,7 @@ public:
    *  maintained by this object results in undefined behaviour.
    *  @return 0 upon success, EOF otherwise, in which case the error code is set.
    */
-  int fclose()
-  {
-    int result = 0;
-    if (file_)
-    {
-      if (popened_)
-      {
-#ifdef HAVE_PCLOSE
-        result = :: pclose(file_);
-#else
-        result = _pclose(file_);
-#endif
-      }
-      else
-      {
-        result = STDIO_NAMESPACE fclose(file_);
-      }
-      // After calling fclose() once, the FILE* is gone even if fclose() failed.
-      file_ = NULL;
-    }
-    if (result) storeLastError();
-    return result;
-  }
+  int fclose();
 
   /** waits for the associated process (created with popen) to terminate and
    *  returns the exit status of the command as returned by wait4.
@@ -499,7 +517,7 @@ public:
    */
   size_t fwrite(const void *ptr, size_t size, size_t n)
   {
-    return STDIO_NAMESPACE fwrite(ptr, size, n, file_);
+    return :: fwrite(ptr, size, n, file_);
   }
 
   /** reads n elements of data, each size bytes long, from the stream, storing
@@ -515,7 +533,7 @@ public:
    */
   size_t fread(void *ptr, size_t size, size_t n)
   {
-    return STDIO_NAMESPACE fread(ptr, size, n, file_);
+    return :: fread(ptr, size, n, file_);
   }
 
   /** forces a write of all user-space buffered data for the given output or
@@ -525,7 +543,7 @@ public:
    */
   int fflush()
   {
-    int result = STDIO_NAMESPACE fflush(file_);
+    int result = :: fflush(file_);
     if (result) storeLastError();
     return result;
   }
@@ -534,7 +552,7 @@ public:
    *  cast to an int, or EOF on end of file or error.
    *  @return next character from stream or EOF
    */
-  int fgetc() { return STDIO_NAMESPACE fgetc(file_); }
+  int fgetc() { return :: fgetc(file_); }
 
   /** The three types of buffering available are unbuffered, block buffered, and
    *  line buffered. When an output stream is unbuffered, information appears on
@@ -570,13 +588,13 @@ public:
      */
     (void) this->fseek(0L, SEEK_SET);
 #else
-    STDIO_NAMESPACE rewind(file_);
+    :: rewind(file_);
 #endif
   }
 
   /** clears the end-of-file and error indicators for the stream
    */
-  void clearerr() { STDIO_NAMESPACE clearerr(file_); }
+  void clearerr() { :: clearerr(file_); }
 
   /** tests the end-of-file indicator for the stream, returning non-zero if it
    *  is set. The end-of-file indicator can only be cleared by the function
@@ -590,7 +608,7 @@ public:
     // feof is a macro on some systems. Macros never have namespaces.
     return feof(file_);
 #else
-    return STDIO_NAMESPACE feof(file_);
+    return :: feof(file_);
 #endif
   }
 
@@ -606,7 +624,7 @@ public:
     // ferror is a macro on some systems. Macros never have namespaces.
     return ferror(file_);
 #else
-    return STDIO_NAMESPACE ferror(file_);
+    return :: ferror(file_);
 #endif
   }
 
@@ -635,7 +653,7 @@ public:
    *  @param buf pointer to buffer of size BUFSIZ as declared in cstdio, or NULL
    *  @return 0 upon success, nonzero otherwise, in which case the error code may be set
    */
-  void setbuf(char *buf) { STDIO_NAMESPACE setbuf(file_, buf); }
+  void setbuf(char *buf) { :: setbuf(file_, buf); }
 
   /** The three types of buffering available are unbuffered, block buffered, and
    *  line buffered. When an output stream is unbuffered, information appears on
@@ -654,7 +672,7 @@ public:
    */
   int setvbuf(char * buf, int modes, size_t n)
   {
-    int result = STDIO_NAMESPACE setvbuf(file_, buf, modes, n);
+    int result = :: setvbuf(file_, buf, modes, n);
     if (result) storeLastError();
     return result;
   }
@@ -686,7 +704,7 @@ public:
    *  @param c character
    *  @return the character written as an unsigned char cast to an int or EOF on error
    */
-  int fputc(int c) { return STDIO_NAMESPACE fputc(c, file_); }
+  int fputc(int c) { return :: fputc(c, file_); }
 
   /** reads in at most one less than n characters from stream and stores them
    *  into the buffer pointed to by s. Reading stops after an EOF or a newline.
@@ -696,13 +714,13 @@ public:
    *  @param n buffer size
    *  @return pointer to string
    */
-  char *fgets(char *s, int n) { return STDIO_NAMESPACE fgets(s, n, file_); }
+  char *fgets(char *s, int n) { return :: fgets(s, n, file_); }
 
   /** writes the string s to stream, without its trailing '@\0'.
    *  @param s string to be written
    *  @return a non-negative number on success, or EOF on error.
    */
-  int fputs(const char *s) { return STDIO_NAMESPACE fputs(s, file_); }
+  int fputs(const char *s) { return :: fputs(s, file_); }
 
   /** pushes c back to stream, cast to unsigned char, where it is available for
    *  subsequent read operations. Pushed - back characters will be returned in
@@ -710,7 +728,7 @@ public:
    *  @param c character to push back
    *  @return c on success, or EOF on error.
    */
-  int ungetc(int c) { return STDIO_NAMESPACE ungetc(c, file_); }
+  int ungetc(int c) { return :: ungetc(c, file_); }
 
   /** sets the file position indicator for the stream pointed to by stream. The
    *  new position, measured in bytes, is obtained by adding offset bytes to the
@@ -737,11 +755,11 @@ public:
     {
       case SEEK_END:
         // flush write buffer, if any, so that the file size is correct
-        STDIO_NAMESPACE fflush(file_);
+        :: fflush(file_);
 #if 0
         // Python implementation based on _lseeki64(). May be unsafe because
         // there is no guarantee that fflush also empties read buffers.
-        STDIO_NAMESPACE fflush(file_);
+        :: fflush(file_);
 #ifdef fileno
         if (_lseeki64(   fileno(file_), 0, 2) == -1)
 #else
@@ -769,7 +787,7 @@ public:
         break;
 #endif
       case SEEK_CUR:
-        if (STDIO_NAMESPACE fgetpos(file_, &pos) != 0)
+        if (:: fgetpos(file_, &pos) != 0)
         {
           storeLastError();
           return -1;
@@ -782,8 +800,6 @@ public:
         break;
     }
     result = this->fsetpos(&off2);
-#elif defined(__BEOS__)
-    result = :: _fseek(fp, offset, whence);
 #else
 #ifdef HAVE_FSEEKO
 #ifdef EXPLICIT_LFS_64
@@ -792,7 +808,7 @@ public:
     result = :: fseeko(file_, off, whence);
 #endif
 #else
-    result = STDIO_NAMESPACE fseek(file_, off, whence);
+    result = :: fseek(file_, off, whence);
 #endif
 #endif
     if (result) storeLastError();
@@ -804,7 +820,6 @@ public:
    */
   offile_off_t ftell()
   {
-    offile_off_t result;
 #ifdef _WIN32
     // Windows does not have a 64-bit ftell, and _telli64 cannot be used
     // because it operates on file descriptors and ignores FILE buffers.
@@ -816,8 +831,9 @@ public:
       storeLastError();
       return -1;
     }
-    return pos;
+    return OFstatic_cast(offile_off_t, pos);
 #else
+    offile_off_t result;
 #ifdef HAVE_FSEEKO
 #ifdef EXPLICIT_LFS_64
     result = :: ftello64(file_);
@@ -825,11 +841,11 @@ public:
     result = :: ftello(file_);
 #endif
 #else
-    result = STDIO_NAMESPACE ftell(file_);
-#endif
+    result = :: ftell(file_);
 #endif
     if (result < 0) storeLastError();
     return result;
+#endif
   }
 
   /** alternate interface equivalent to ftell, storing the current value of the
@@ -846,7 +862,7 @@ public:
     // MinGW and QNX have EXPLICIT_LFS_64 but no fgetpos64()
     result = :: fgetpos64(file_, pos);
 #else
-    result = STDIO_NAMESPACE fgetpos(file_, pos);
+    result = :: fgetpos(file_, pos);
 #endif
     if (result) storeLastError();
     return result;
@@ -866,7 +882,7 @@ public:
     // MinGW and QNX have EXPLICIT_LFS_64 but no fsetpos64()
     result = :: fsetpos64(file_, pos);
 #else
-    result = STDIO_NAMESPACE fsetpos(file_, pos);
+    result = :: fsetpos(file_, pos);
 #endif
     if (result) storeLastError();
     return result;
@@ -882,7 +898,7 @@ public:
     int result = 0;
     va_list ap;
     va_start(ap, format);
-    result = STDIO_NAMESPACE vfprintf(file_, format, ap);
+    result = :: vfprintf(file_, format, ap);
     va_end(ap);
     return result;
   }
@@ -894,7 +910,7 @@ public:
    */
    int vfprintf(const char *format, va_list arg)
    {
-     return STDIO_NAMESPACE vfprintf(file_, format, arg);
+     return :: vfprintf(file_, format, arg);
    }
 
   // we cannot emulate fscanf because we would need vfscanf for this
@@ -948,7 +964,7 @@ public:
    */
   int fwide(int mode)
   {
-    return STDIO_NAMESPACE fwide(file_, mode);
+    return :: fwide(file_, mode);
   }
 
   /** reads a wide character from stream and returns it. If the end of stream is
@@ -959,7 +975,7 @@ public:
    */
   wint_t fgetwc()
   {
-    wint_t result = STDIO_NAMESPACE fgetwc(file_);
+    wint_t result = :: fgetwc(file_);
     if (result == WEOF) storeLastError();
     return result;
   }
@@ -972,7 +988,7 @@ public:
    */
   wint_t fputwc(wchar_t wc)
   {
-    wint_t result = STDIO_NAMESPACE fputwc(wc, file_);
+    wint_t result = :: fputwc(wc, file_);
     if (result == WEOF) storeLastError();
     return result;
   }
@@ -993,7 +1009,7 @@ public:
    */
   wint_t ungetwc(wint_t wc)
   {
-    wint_t result = STDIO_NAMESPACE ungetwc(wc, file_);
+    wint_t result = :: ungetwc(wc, file_);
     if (result == WEOF) storeLastError();
     return result;
   }
@@ -1008,7 +1024,7 @@ public:
     int result = 0;
     va_list ap;
     va_start(ap, format);
-    result = STDIO_NAMESPACE vfwprintf(file_, format, ap);
+    result = :: vfwprintf(file_, format, ap);
     va_end(ap);
     return result;
   }
@@ -1020,7 +1036,7 @@ public:
    */
    int vfwprintf(const wchar_t *format, va_list arg)
    {
-     return STDIO_NAMESPACE vfwprintf(file_, format, arg);
+     return :: vfwprintf(file_, format, arg);
    }
 
   // we cannot emulate fwscanf because we would need vfwscanf for this
