@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2021, OFFIS e.V.
+ *  Copyright (C) 2000-2024, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -769,19 +769,14 @@ class DCMTK_OFSTD_EXPORT OFStandard
      *  decimal representation to internal double-precision format.
      *  Unlike the atof() function defined in Posix, this implementation
      *  is not affected by a locale setting, the radix character is always
-     *  assumed to be '.'
-     *  This implementation does not set errno if the input cannot be parsed
-     *  and it does not implement special handling for overflow/underflow.
+     *  assumed to be '.'. This implementation never modifies errno.
      *  It does handle "NaN" and "Inf" (case insensitive; following
-     *  characters are ignore). A return code indicates whether or not
+     *  characters are ignored). A return code indicates whether or not
      *  a successful conversion could be performed.
-     *  The precision of this implementation is limited to approx. 9
-     *  decimal digits.
-     *  @note The use of this implementation can be disabled by defining
-     *    the macro DISABLE_OFSTD_ATOF at compile time; in this case,
-     *    the locale dependent Posix implementation of sscanf is used and
-     *    the application is responsible for making sure that the Posix locale
-     *    is activated at all times.
+     *  Very large numbers that cannot be represented as a double will
+     *  cause the success value to be set to false, unless the old
+     *  implementation is enabled through the ENABLE_OLD_OFSTD_ATOF_IMPLEMENTATION
+     *  macro, in which case HUGE_VAL and success will be returned.
      *  @param s
      *    A decimal ASCII floating-point number, optionally preceded by white
      *    space. Must have form "-I.FE-X", where I is the integer part of the
@@ -809,18 +804,18 @@ class DCMTK_OFSTD_EXPORT OFStandard
       *  This implementation guarantees that the given string size
       *  is always respected by using strlcpy to copy the formatted
       *  string into the target buffer.
-      *  @note The use of this implementation can be disabled by defining
-      *    the macro DISABLE_OFSTD_FTOA at compile time; in this case,
-      *    the locale dependent Posix implementation of sprintf is used and
-      *    the application is responsible for making sure that the Posix locale
-      *    is activated at all times.
       *  @param target pointer to target string buffer
       *  @param targetSize size of target string buffer
       *  @param value double value to be formatted
       *  @param flags processing flags. Any of the flags defined below
       *    can be combined by bit-wise or.
       *  @param width width from format (%8d), or 0
-      *  @param precision precision from format (%.3d), or -1
+      *  @param precision precision from format (%.3d),
+      *    -1 for default precision,
+      *    -2, when used with default "%g" format, causes the shortest
+      *        string to be created that can be converted back
+      *        to a double equalling "value". With "%e" or "%f" format,
+      *        prints default precision.
       */
      static void ftoa(char *target,
                       size_t targetSize,
@@ -834,19 +829,23 @@ class DCMTK_OFSTD_EXPORT OFStandard
       */
      //@{
 
-     /// Use %e or %E conversion format instead of %g or %G
+     /// Use scientific format (equivalent to %e or %E in printf),
+     /// instead of the default, which is equivalent to %g or %G.
+     /// If both ftoa_format_e and ftoa_format_f are specified,
+     /// ftoa_format_e format is used.
      static const unsigned int ftoa_format_e;
 
-     /// Use %f or %F conversion format instead of %g or %G
+     /// Use fixed format (equivalent to %f or %F in printf),
+     /// instead of the default, which is equivalent to %g or %G
+     /// If both ftoa_format_e and ftoa_format_f are specified,
+     /// ftoa_format_e format is used.
      static const unsigned int ftoa_format_f;
 
-     /// Use %E, %F or %G conversion format instead of %e, %f or %g
+     /// Use an uppercase 'E' letter (like %E, %F or %G in printf)
      static const unsigned int ftoa_uppercase;
 
-     /** convert value to alternate form. The result will always contain
-      *  a decimal point, even if no digits follow the point. For g and G
-      *  conversions, trailing zeroes will not be removed from the result.
-      */
+     /// convert value to alternate form. The result will always contain
+     /// a decimal point, even if no digits follow the point.
      static const unsigned int ftoa_alternate;
 
      /// left-justify number be within the field
@@ -1073,9 +1072,10 @@ class DCMTK_OFSTD_EXPORT OFStandard
     /** This function performs a DNS lookup of an IP address based on a hostname.
      *  If a DNS lookup yields multiple IP addresses, only the first one is returned.
      *  @param name hostname
+     *  @param protocolFamily AF_INET for IPv4, AF_INET6 for IPv6 or AF_UNSPEC for both
      *  @param result a OFSockAddr instance in which the result is stored
      */
-    static void getAddressByHostname(const char *name, OFSockAddr& result);
+    static void getAddressByHostname(const char *name, int protocolFamily, OFSockAddr& result);
 
     /** Thread-safe version of getgrnam.
      *  @param name the group name.
@@ -1165,6 +1165,49 @@ class DCMTK_OFSTD_EXPORT OFStandard
     */
     static void forceSleep(Uint32 seconds);
 
+    /** sanitize a filename (NOT a path name!) by replacing all path
+     *  separators with underscores. This avoids possible path traversal
+     *  vulnerabilities if malformed data read from file or received over
+     *  a network is used as part of a filename.
+     *  @param fname filename to be sanitized
+     */
+    static void sanitizeFilename(OFString& fname);
+
+    /** sanitize a filename (NOT a path name!) by replacing all path
+     *  separators with underscores. This avoids possible path traversal
+     *  vulnerabilities if malformed data read from file or received over
+     *  a network is used as part of a filename.
+     *  @param fname filename to be sanitized
+     */
+    static void sanitizeFilename(char *fname);
+
+    /** retrieve the name of the default directory for support data.
+     *  On Windows, this method resolves environment variables such as
+     *  \%PROGRAMDATA% in the path, on Posix platforms it just returns
+     *  DEFAULT_SUPPORT_DATA_DIR.
+     *  @return name of the default directory for support data
+     */
+    static OFString getDefaultSupportDataDir();
+
+    /** retrieve the name of the default directory for configuration files.
+     *  On Windows, this method resolves environment variables such as
+     *  \%PROGRAMDATA% in the path, on Posix platforms it just returns
+     *  DEFAULT_CONFIGURATION_DIR.
+     *  @return name of the default directory for configuration files
+     */
+    static OFString getDefaultConfigurationDir();
+
+    /** check if the character is a whitespace character assuming the C locale.
+     *  The standard ::isspace function is locale-dependent, which is slow and
+     *  may lead to surprising behavior.  Further, it is undefined for char
+     *  values -127 to 0, requiring the caller to cast the argument to unsigned
+     *  char.
+     *  @param ch the character to check
+     *  @return true if the character is a whitespace character, false otherwise
+     */
+    static bool isspace(char ch);
+
+
  private:
 
     /** private implementation of strlcpy. Called when strlcpy
